# Changelog

## v0.1.0 (2022-07-16)

### Features

- batch downloads of profile photos and videos
- setting up save path/filename using template strings
- simultaneous download / API requests limiting
- passing profile names using a file
- restricting downloads to only photos / only videos
- skipping files that are already downloaded (same filename)
- some basic output
